Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2482)

Unified Diff: cc/resources/tiling_set_raster_queue_required.cc

Issue 1107033002: cc: Rename picture layer tiling method to reflect its new functionality. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/resources/tiling_set_raster_queue_all.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/resources/tiling_set_raster_queue_required.cc
diff --git a/cc/resources/tiling_set_raster_queue_required.cc b/cc/resources/tiling_set_raster_queue_required.cc
index b44ee084879bd0b9d798b359c84f09b69f3502d7..71d86aa05fad7a3038a6e948b8954ad79037976f 100644
--- a/cc/resources/tiling_set_raster_queue_required.cc
+++ b/cc/resources/tiling_set_raster_queue_required.cc
@@ -108,7 +108,7 @@ TilingSetRasterQueueRequired::TilingIterator::TilingIterator(
// for occlusion, since the tile's internal state has not yet been updated.
if (current_tile_ && current_tile_->NeedsRaster() &&
!tiling_->IsTileOccluded(current_tile_)) {
- tiling_->UpdateTileAndTwinPriority(current_tile_);
+ tiling_->UpdateTilePriority(current_tile_);
return;
}
++(*this);
@@ -135,7 +135,7 @@ TilingSetRasterQueueRequired::TilingIterator&
// If the tile is occluded, we also can skip it. Note that we use the tiling
// check for occlusion, since tile's internal state has not yet been updated
// (by UpdateTileAndTwinPriority). The tiling check does not rely on tile's
// internal state (it is, in fact, used to determine the tile's state).
if (tiling_->IsTileOccluded(current_tile_))
continue;
@@ -146,7 +146,7 @@ TilingSetRasterQueueRequired::TilingIterator&
}
if (current_tile_)
- tiling_->UpdateTileAndTwinPriority(current_tile_);
+ tiling_->UpdateTilePriority(current_tile_);
return *this;
}
« no previous file with comments | « cc/resources/tiling_set_raster_queue_all.cc ('k') | no next file » | no next file with comments »
@@ -135,7 +135,7 @@ TilingSetRasterQueueRequired::TilingIterator&
// If the tile is occluded, we also can skip it. Note that we use the tiling
// check for occlusion, since tile's internal state has not yet been updated
- // (by UpdateTileAndTwinPriority). The tiling check does not rely on tile's
+ // (by UpdateTilePriority). The tiling check does not rely on tile's
// internal state (it is, in fact, used to determine the tile's state).
if (tiling_->IsTileOccluded(current_tile_))

Powered by Google App Engine
This is Rietveld 408576698